ProgramConfig class

Configuration for a single program in the workspace

Constructors

ProgramConfig({required Idl idl, required PublicKey programId, String? name, Map<String, dynamic>? metadata})
const
ProgramConfig.fromJson(Map<String, dynamic> json)
Create from JSON configuration
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
idl Idl
final
metadata Map<String, dynamic>?
final
name String?
final
programId PublicKey
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited